@@ -28,6 +28,7 @@ class Module:
 
     PARAMS_NEW = "new"
     PARAMS_LEGACY = "legacy"
+    EXPECTED_CLASS = "Py3status"
 
     def __init__(self, module, user_modules, py3_wrapper, instance=None):
         """
@@ -101,17 +102,16 @@ class Module:
     def __repr__(self):
         return "<Module {}>".format(self.module_full_name)
 
-    @staticmethod
-    def load_from_file(filepath):
+    @classmethod
+    def load_from_file(cls, filepath):
         """
         Return user-written class object from given path.
         """
         class_inst = None
-        expected_class = "Py3status"
         module_name, file_ext = os.path.splitext(os.path.split(filepath)[-1])
         if file_ext.lower() == ".py":
             py_mod = imp.load_source(module_name, filepath)
-            if hasattr(py_mod, expected_class):
+            if hasattr(py_mod, cls.EXPECTED_CLASS):
                 class_inst = py_mod.Py3status()
         return class_inst
 
@@ -619,8 +619,36 @@ class Module:
                 pass
 
             # module configuration
+            fn = self._py3_wrapper.get_config_attribute
             mod_config = self.config["py3_config"].get(module, {})
 
+            # resources
+            if self.config.get("resources"):
+                module = self.module_full_name
+                resources = fn(module, "resources")
+                if not hasattr(resources, "none_setting"):
+                    exception = True
+                    if isinstance(resources, list):
+                        exception = False
+                        for resource in resources:
+                            if not isinstance(resource, tuple) or len(resource) != 3:
+                                exception = True
+                                break
+                    if exception:
+                        err = "Invalid `resources` attribute, "
+                        err += "should be a list of 3-tuples. "
+                        raise TypeError(err)
+
+                    from fnmatch import fnmatch
+
+                    for resource in resources:
+                        key, resource, value = resource
+                        for setting in self.config["resources"]:
+                            if fnmatch(setting, resource):
+                                value = self.config["resources"][setting]
+                                break
+                        self.config["py3_config"][module][key] = value
+
             # process any deprecated configuration settings
             try:
                 deprecated = class_inst.Meta.deprecated
@@ -762,9 +790,6 @@ class Module:
                     self.add_udev_trigger(trigger_action, param[8:])
 
             # allow_urgent
-            # get the value form the config or use the module default if
-            # supplied.
-            fn = self._py3_wrapper.get_config_attribute
             param = fn(self.module_full_name, "allow_urgent")
             if hasattr(param, "none_setting"):
                 param = True
