@@ -15,6 +15,7 @@ Format placeholders:
 Requires:
     pacman-contrib: contributed scripts and tools for pacman systems
     auracle: a flexible command line client for arch linux's user repository
+    trizen: lightweight pacman wrapper and AUR helper
     yay: yet another yogurt. pacman wrapper and aur helper written in go
 ```
 
@@ -46,7 +47,7 @@ class Py3status:
     def post_config_hook(self):
         helper = {
             "pacman": self.py3.check_commands(["checkupdates"]),
-            "aur": self.py3.check_commands(["auracle", "yay", "cower"]),
+            "aur": self.py3.check_commands(["auracle", "trizen", "yay", "cower"]),
         }
         if self.format:
             placeholders = self.py3.get_placeholders_list(self.format)
@@ -84,8 +85,8 @@ class Py3status:
         try:
             updates = self.py3.command_output(["auracle", "sync"])
             return len(updates.splitlines())
-        except self.py3.CommandError:
-            return None
+        except self.py3.CommandError as ce:
+            return None if ce.error else 0
 
     def _get_cower_updates(self):
         try:
@@ -94,6 +95,13 @@ class Py3status:
         except self.py3.CommandError as ce:
             return len(ce.output.splitlines())
 
+    def _get_trizen_updates(self):
+        try:
+            updates = self.py3.command_output(["trizen", "-Suaq"])
+            return len(updates.splitlines())
+        except self.py3.CommandError:
+            return None
+
     def _get_yay_updates(self):
         try:
             updates = self.py3.command_output(["yay", "-Qua"])
