@@ -14,8 +14,7 @@ from time import time
 from uuid import uuid4
 
 from py3status import exceptions
-from py3status.constants import COLOR_NAMES
-from py3status.formatter import Formatter, Composite
+from py3status.formatter import Formatter, Composite, expand_color
 from py3status.request import HttpResponse
 from py3status.storage import Storage
 from py3status.util import Gradients
@@ -111,6 +110,7 @@ class Py3:
         self._english_env = dict(os.environ)
         self._english_env["LC_ALL"] = "C"
         self._english_env["LANGUAGE"] = "C"
+        self._format_color_names = {}
         self._format_placeholders = {}
         self._format_placeholders_cache = {}
         self._is_python_2 = sys.version_info < (3, 0)
@@ -157,9 +157,13 @@ class Py3:
                 # use color "hidden" to hide blocks
                 if _name == "hidden":
                     param = "hidden"
+                # TODO: removing this statement does not fail "test_color_10()" but would fail
+                # easily in the bar. the test is there to raise awareness about this.
+                # TODO: "test_color_11()" shows how the tests can be incorrect as it does not print
+                # everything correctly (i.e. orange vs ORaNgE) due to non composite/formatter code.
                 elif hasattr(param, "none_setting"):
                     # see if named color and use if it is
-                    param = COLOR_NAMES.get(_name)
+                    param = expand_color(_name)
                 elif param is None:
                     param = self._none_color
             # if a non-color parameter and was not set then set to default
@@ -169,25 +173,10 @@ class Py3:
         return self._config_setting[name]
 
     def _get_color(self, color):
-        if not color:
-            return
-        # fix any hex colors so they are #RRGGBB
-        if color.startswith("#"):
-            color = color.upper()
-            if len(color) == 4:
-                color = (
-                    "#"
-                    + color[1]
-                    + color[1]
-                    + color[2]
-                    + color[2]
-                    + color[3]
-                    + color[3]
-                )
-            return color
-
-        name = "color_%s" % color
-        return self._get_config_setting(name)
+        if color:
+            if color[0] == "#":
+                return expand_color(color)
+            return self._get_config_setting("color_" + color)
 
     def _thresholds_init(self):
         """
@@ -718,22 +707,45 @@ class Py3:
         self._format_placeholders_cache[format_string][key] = False
         return False
 
-    def get_color_names_list(self, format_strings):
+    def get_color_names_list(self, format_string, matches=None):
         """
         Returns a list of color names in ``format_string``.
 
-        :param format_strings: Accepts a format string or a list of format strings.
+        :param format_string: Accepts a format string.
+        :param matches: Filter results with a string or a list of strings.
+
+        If ``matches`` is provided then it is used to filter the result
+        using fnmatch so the following patterns can be used:
+
+        .. code-block:: none
+
+            * 	    matches everything
+            ? 	    matches any single character
+            [seq] 	matches any character in seq
+            [!seq] 	matches any character not in seq
         """
-        if not format_strings:
-            return []
         if not getattr(self._py3status_module, "thresholds", None):
             return []
-        if isinstance(format_strings, basestring):
-            format_strings = [format_strings]
-        names = set()
-        for string in format_strings:
-            names.update(self._formatter.get_color_names(string))
-        return list(names)
+        elif not format_string:
+            return []
+
+        if format_string not in self._format_color_names:
+            names = self._formatter.get_color_names(format_string)
+            self._format_color_names[format_string] = names
+        else:
+            names = self._format_color_names[format_string]
+
+        if not matches:
+            return list(names)
+        elif isinstance(matches, basestring):
+            matches = [matches]
+        # filter matches
+        found = set()
+        for match in matches:
+            for name in names:
+                if fnmatch(name, match):
+                    found.add(name)
+        return list(found)
 
     def get_placeholders_list(self, format_string, matches=None):
         """
